@@ -48,7 +48,6 @@ def normalize(text):
     # fix windows problems
     text = text.replace("\u2500", "-")
     text = text.replace("\r", "")
-    text = text.replace(" \n", " ⏎\n")
     return text
 
 
@@ -56,7 +55,7 @@ class Example:
     def __init__(self, files: str | dict[str, str]):
         """
         Parameters:
-            files: a collecton of files where inline-snapshot opperates on,
+            files: a collection of files where inline-snapshot operates on,
                    or just a string which will be saved as *test_something.py*.
         """
         if isinstance(files, str):
@@ -225,11 +224,12 @@ class Example:
         env: dict[str, str] = {},
         changed_files: Snapshot[dict[str, str]] | None = None,
         report: Snapshot[str] | None = None,
+        error: Snapshot[str] | None = None,
         stderr: Snapshot[str] | None = None,
         returncode: Snapshot[int] = 0,
         stdin: bytes = b"",
     ) -> Example:
-        """Run pytest with the given args and env variables in an seperate
+        """Run pytest with the given args and env variables in an separate
         process.
 
         It can be used to test the interaction between your code and pytest, but it is a bit slower than `run_inline`
@@ -321,6 +321,19 @@ class Example:
 
                 assert report_str == report, repr(report_str)
 
+            if error is not None:
+                assert (
+                    error
+                    == "\n".join(
+                        [
+                            line
+                            for line in result_stdout.splitlines()
+                            if line and line[:2] in ("> ", "E ")
+                        ]
+                    )
+                    + "\n"
+                )
+
             if changed_files is not None:
                 current_files = {}
 
